.. lontras documentation master file, created by
   sphinx-quickstart on Sat Jan 11 23:15:01 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Lontras |version| documentation
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Indices and tables
==================

*   :ref:`genindex`
*   :ref:`modindex`
*   :ref:`search`
